@@ -24,7 +24,6 @@ sub rollout {
     my $log = $ssh->capture("mkdir -p " . $self->config->{deploy_dir});
     $self->log($ssh, $log);
     $self->checkout($ssh);
-    $self->post_rollout($ssh);
 
     return;
 }
@@ -36,12 +35,11 @@ sub rollout_timestamped {
     my $deploy_dir = join('/', $self->config->{root}, 'releases', time);
     my $current = join('/', $self->config->{root}, 'current');
     my $log = $ssh->capture("mkdir -p " . $deploy_dir);
-    $self->config->{deploy_dir} = $deploy_dir;
-    $self->checkout($ssh);
     $log .= $ssh->capture(
         "unlink " . $current . "; ln -s " . $deploy_dir . " " . $current);
+    $self->config->{deploy_dir} = $deploy_dir;
     $self->log($ssh, $log);
-    $self->post_rollout($ssh);
+    $self->checkout($ssh);
 
     return;
 }
@@ -73,7 +71,7 @@ sub rollback_timestamped {
             push(@past, $rel);
         }
     }
-    $deploy_dir = join('/', $self->config->{root}, 'releases', pop(@past));
+    $deploy_dir = join('/', $self->config->{root}, pop(@past));
     my $log = $ssh->capture(
         "unlink " . $current . "; ln -s " . $deploy_dir . " " . $current);
     $self->log($ssh, $log);
@@ -158,59 +156,21 @@ sub cleanup_timestamped {
 }
 
 sub restart_phased {
-    my ($self, $ssh) = @_;
+    my ($self, $ssh, $conf) = @_;
 
     $self->log($ssh, "running restart_phased task ...");
-    unless ($ssh->test($self->_init_command('restart'))) {
+    unless ($ssh->test("sudo " . $self->config->{init} . " restart")) {
         $self->log(
             'restart failed: ' . $ssh->error . ' trying stop -> start instead');
-        $ssh->test($self->_init_command('stop'));
-
-        # give time to exit
-        sleep 2;
-        $ssh->test($self->_init_command('start'))
+        $ssh->test("sudo " . $self->config->{init} . " stop");
+        $ssh->test("sudo " . $self->config->{init} . " start")
             or $self->error('restart failed: ' . $ssh->error);
         return;
     }
 
     # my $exp = Expect->init($pty);
     # $exp->interact();
-    $self->log(
-        $ssh,
-        'restarted '
-            . (
-              $self->config->{systemd}
-            ? $self->config->{systemd}
-            : $self->config->{init}));
-
-    return;
-}
-
-sub reload_phased {
-    my ($self, $ssh) = @_;
-
-    $self->log($ssh, "running reload_phased task ...");
-    unless ($ssh->test($self->_init_command('restart'))) {
-        $self->log(
-            'reload failed: ' . $ssh->error . ' trying stop -> start instead');
-        $ssh->test($self->_init_command("stop"));
-
-        # give time to exit
-        sleep 2;
-        $ssh->test($self->_init_command("start"))
-            or $self->error('restart failed: ' . $ssh->error);
-        return;
-    }
-
-    # my $exp = Expect->init($pty);
-    # $exp->interact();
-    $self->log(
-        $ssh,
-        'restarted '
-            . (
-              $self->config->{systemd}
-            ? $self->config->{systemd}
-            : $self->config->{init}));
+    $self->log($ssh, 'restarted ' . $self->config->{init});
 
     return;
 }
@@ -221,65 +181,5 @@ sub send_notify {
     return;
 }
 
-sub post_rollout {
-    my ($self, $ssh) = @_;
-
-    return
-        unless (exists $self->config->{post_rollout}
-        and defined $self->config->{post_rollout});
-
-    $self->log($ssh,
-              'running post_rollout script "'
-            . $self->config->{post_rollout}
-            . '" ...');
-    unless (
-        $ssh->test(
-                  'cd '
-                . $self->config->{deploy_dir} . ' && '
-                . $self->config->{post_rollout}))
-    {
-        $self->error("post_rollout script failed: " . $ssh->error);
-    }
-    return;
-}
-
-sub _init_command {
-    my ($self, $command) = @_;
-
-    if (defined $self->config->{systemd}) {
-        return "sudo systemctl $command " . $self->config->{systemd} . ".service";
-    }
-    else {
-        return "sudo " . $self->config->{init} . " $command";
-    }
-    return;
-}
 
 __PACKAGE__->meta->make_immutable;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Giovanni::Stages
-
-=head1 VERSION
-
-version 1.12
-
-=head1 AUTHOR
-
-Lenz Gschwendtner <mail@norbu09.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by ideegeo Group Limited.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
